@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2007 by Tobias Koenig <tokoe@kde.org>                   *
+ *   Copyright (C) 2008 Matthias Fuchs <mat69@gmx.net>                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,22 +22,49 @@
 #define CONFIGWIDGET_H
 
 #include <QtGui/QWidget>
+#include <Plasma/DataEngine>
 
 class ComicModel;
+class QCheckBox;
 class QComboBox;
+class QSortFilterProxyModel;
+class QPushButton;
 
 class ConfigWidget : public QWidget
 {
+        Q_OBJECT
     public:
-        ConfigWidget( QWidget *parent );
+        ConfigWidget( Plasma::DataEngine *engine, QWidget *parent );
         ~ConfigWidget();
 
         void setComicIdentifier( const QString &comic );
         QString comicIdentifier() const;
 
+        void setShowComicUrl( bool show );
+        bool showComicUrl() const;
+        void setShowComicAuthor( bool show );
+        bool showComicAuthor() const;
+        void setShowComicTitle( bool show );
+        bool showComicTitle() const;
+        void setShowComicIdentifier( bool show );
+        bool showComicIdentifier() const;
+        void setArrowsOnHover( bool arrows );
+        bool arrowsOnHover() const;
+
+    protected slots:
+        void getNewStuff();
+
     private:
         QComboBox *mComicIdentifier;
+        QCheckBox *mShowComicUrl;
+        QCheckBox *mShowComicAuthor;
+        QCheckBox *mShowComicTitle;
+        QCheckBox *mShowComicIdentifier;
+        QCheckBox *mShowArrowsOnHover;
+        QPushButton *mNewStuff;
         ComicModel *mModel;
+        Plasma::DataEngine *mEngine;
+        QSortFilterProxyModel *mProxyModel;
 };
 
 #endif
