@@ -2,16 +2,16 @@
  *   Copyright (C) 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Lesser/Library General Public License version 2,
+ *   it under the terms of the GNU General Public License version 2,
  *   or (at your option) any later version, as published by the Free
  *   Software Foundation
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Lesser/Library General Public License for more details
+ *   GNU General Public License for more details
  *
- *   You should have received a copy of the GNU Lesser/Library General Public
+ *   You should have received a copy of the GNU General Public
  *   License along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
@@ -22,8 +22,8 @@
 
 #include "BaseModel.h"
 #include <QDir>
-
-class KDirWatch;
+#include <KDirLister>
+#include <KFileItem>
 
 namespace Models {
 
@@ -37,12 +37,14 @@ protected:
     void load();
 
 private:
-    static KDirWatch * m_dirWatch;
+    KDirLister * m_dirLister;
     QString m_dirPath;
     QDir::SortFlags m_sort;
 
 private Q_SLOTS:
-    void dirty(const QString & dirPath);
+    void clear();
+    void deleteItem(const KFileItem & fileItem);
+    void newItems(const KFileItemList & items);
 };
 
 } // namespace Models
